@@ -72,7 +72,7 @@ event::set_status( const char a_status  )
 void 
 event::make_clock( )
 {
-    m_status = (char) EVENT_MIDI_CLOCK;
+    m_status = (unsigned char) EVENT_MIDI_CLOCK;
 }
 
 void 
@@ -227,7 +227,7 @@ event::get_note_velocity()
 void 
 event::print()
 {
-    printf( "[%06ld] [%04X] %02X ",
+    printf( "[%06ld] [%04lX] %02X ",
 	    m_timestamp,
 	    m_size,
 	    m_status );
