@@ -112,6 +112,7 @@ const unsigned long c_triggers =   0x24240004;
 const unsigned long c_notes =      0x24240005;
 const unsigned long c_timesig =    0x24240006;
 const unsigned long c_bpmtag =     0x24240007;
+const unsigned long c_triggers_new =   0x24240008;
 
 const unsigned long c_midictrl =   0x24240010;
 
@@ -154,7 +155,7 @@ const int c_redraw_ms = 40;
 
 /* consts for perform editor */
 const int c_names_x = 6 * 24;
-const int c_names_y = 12;
+const int c_names_y = 22;
 const int c_perf_scale_x = 32; /*ticks per pixel */
 
 extern bool global_showmidi;
@@ -165,6 +166,7 @@ extern bool global_with_jack_transport;
 extern bool global_with_jack_master;
 extern bool global_with_jack_master_cond;
 extern bool global_jack_start_mode;
+extern bool global_manual_alsa_ports;
 
 extern std::string global_filename;
 
@@ -298,8 +300,12 @@ const char c_chord_text[][8] =
     "VIII"
 };
 
-
- 
+enum mouse_action_e 
+{
+    e_action_select,
+    e_action_draw,
+    e_action_grow
+};
 
 
 #endif
