@@ -46,19 +46,19 @@ mainwnd::mainwnd(perform *a_p)
     m_menu_help    = manage( new Menu());
     
     /* fill with items */
-    m_menu_file->items().push_back(MenuElem("New", slot(*this,&mainwnd::file_new_dialog)));
+    m_menu_file->items().push_back(MenuElem("New", mem_fun(*this,&mainwnd::file_new_dialog)));
     m_menu_file->items().push_back(SeparatorElem());
-    m_menu_file->items().push_back(MenuElem("Open...",   slot(*this,&mainwnd::file_open_dialog)));
-    m_menu_file->items().push_back(MenuElem("Import...", slot(*this,&mainwnd::file_import_dialog)));
+    m_menu_file->items().push_back(MenuElem("Open...",   mem_fun(*this,&mainwnd::file_open_dialog)));
+    m_menu_file->items().push_back(MenuElem("Import...", mem_fun(*this,&mainwnd::file_import_dialog)));
     m_menu_file->items().push_back(SeparatorElem());
-    m_menu_file->items().push_back(MenuElem("Save", slot(*this,&mainwnd::file_save_dialog)));
-    m_menu_file->items().push_back(MenuElem("Save As...", slot(*this,&mainwnd::file_saveas_dialog)));
+    m_menu_file->items().push_back(MenuElem("Save", mem_fun(*this,&mainwnd::file_save_dialog)));
+    m_menu_file->items().push_back(MenuElem("Save As...", mem_fun(*this,&mainwnd::file_saveas_dialog)));
     m_menu_file->items().push_back(SeparatorElem());
-    m_menu_file->items().push_back(MenuElem("Options...", slot(*this,&mainwnd::options_dialog)));
+    m_menu_file->items().push_back(MenuElem("Options...", mem_fun(*this,&mainwnd::options_dialog)));
     m_menu_file->items().push_back(SeparatorElem());
-    m_menu_file->items().push_back(MenuElem("Exit", slot(*this,&mainwnd::file_exit_dialog)));
+    m_menu_file->items().push_back(MenuElem("Exit", mem_fun(*this,&mainwnd::file_exit_dialog)));
 
-    m_menu_help->items().push_back(MenuElem("About", slot(*this,&mainwnd::about_dialog)));
+    m_menu_help->items().push_back(MenuElem("About", mem_fun(*this,&mainwnd::about_dialog)));
  
     m_menubar->items().push_front(MenuElem("File", *m_menu_file));
     m_menubar->items().push_back(MenuElem("Help", *m_menu_help));
@@ -67,21 +67,21 @@ mainwnd::mainwnd(perform *a_p)
 
     m_button_stop = manage( new Button( ));
     m_button_stop->add( *manage( new Image(Gdk::Pixbuf::create_from_xpm_data( stop_xpm ))));
-    m_button_stop->signal_clicked().connect( slot(*this,&mainwnd::stop_playing));
+    m_button_stop->signal_clicked().connect( mem_fun(*this,&mainwnd::stop_playing));
     hbox->pack_start(*m_button_stop, false, false);
 
     m_button_play = manage( new Button() );
     m_button_play->add( *manage( new Image(Gdk::Pixbuf::create_from_xpm_data( play2_xpm  ))));
-    m_button_play->signal_clicked().connect(  slot( *this, &mainwnd::start_playing));
+    m_button_play->signal_clicked().connect(  mem_fun( *this, &mainwnd::start_playing));
     hbox->pack_start(*m_button_play, false, false);
 
     //m_button_test = manage( new Button("test") );
-    //m_button_test->signal_clicked().connect(  slot( *this, &mainwnd::test));
+    //m_button_test->signal_clicked().connect(  mem_fun( *this, &mainwnd::test));
     //hbox->pack_start(*m_button_test, false, false);
 
     m_button_perfedit = manage( new Button(  ));
     m_button_perfedit->add( *manage( new Image(Gdk::Pixbuf::create_from_xpm_data( perfedit_xpm  ))));
-    m_button_perfedit->signal_clicked().connect( slot( *this, &mainwnd::open_performance_edit ));
+    m_button_perfedit->signal_clicked().connect( mem_fun( *this, &mainwnd::open_performance_edit ));
     hbox->pack_end(*m_button_perfedit, false, false, 4);
 
     m_adjust_bpm = manage( new Adjustment(  m_mainperf->get_bpm(), 20, 500, 1 ));
@@ -97,11 +97,11 @@ mainwnd::mainwnd(perform *a_p)
     hbox->pack_end(*m_spinbutton_ss, false, false );
     hbox->pack_end(*(manage( new Label( "  set " ))), false, false, 4);
 
-    m_adjust_bpm->signal_value_changed().connect( slot(*this,&mainwnd::adj_callback_bpm ));
-    m_adjust_ss->signal_value_changed().connect( slot(*this,&mainwnd::adj_callback_ss ));
+    m_adjust_bpm->signal_value_changed().connect( mem_fun(*this,&mainwnd::adj_callback_bpm ));
+    m_adjust_ss->signal_value_changed().connect( mem_fun(*this,&mainwnd::adj_callback_ss ));
  
     m_entry_notes = manage( new Entry());
-    m_entry_notes->signal_changed().connect( slot(*this,&mainwnd::edit_callback_notepad ));
+    m_entry_notes->signal_changed().connect( mem_fun(*this,&mainwnd::edit_callback_notepad ));
 
     hbox->pack_start( *m_entry_notes, true, true );
 
@@ -133,12 +133,13 @@ mainwnd::mainwnd(perform *a_p)
 
     m_entry_notes->set_text( * m_mainperf->get_screen_set_notepad(  m_mainperf->get_screenset() )); 
 
-    m_timeout_connect = Glib::signal_timeout().connect(slot(*this,&mainwnd::timer_callback), 25);
+    m_timeout_connect = Glib::signal_timeout().connect(mem_fun(*this,&mainwnd::timer_callback), 25);
     
     m_quit = false;
 
     m_perf_edit = new perfedit( m_mainperf );
-    m_options = new options( *this,  m_mainperf ); 
+    m_options = NULL;
+  
 }
 
  
@@ -180,6 +181,7 @@ mainwnd::timer_callback(  )
 void 
 mainwnd::open_performance_edit( void )
 {
+    m_perf_edit->init_before_show();
     m_perf_edit->show_all();
 }
 
@@ -187,6 +189,9 @@ mainwnd::open_performance_edit( void )
 void 
 mainwnd::options_dialog( void )
 {
+    if ( m_options != NULL )
+        delete m_options;
+    m_options = new options( *this,  m_mainperf ); 
     m_options->show_all(); 
 }
 
@@ -214,8 +219,10 @@ mainwnd::file_new_dialog( void )
 
     Gtk::MessageDialog dialog(*this,
                               "Clear Sequences ?",
+                              false,
                               Gtk::MESSAGE_QUESTION,
-                              (Gtk::ButtonsType)(BUTTONS_OK_CANCEL));
+                              (Gtk::ButtonsType)(BUTTONS_OK_CANCEL),
+                              true );
     
     int result = dialog.run();
 
@@ -258,8 +265,10 @@ mainwnd::file_save_dialog( void )
         
         Gtk::MessageDialog errdialog(*this,
                                      "Error writing file.",
+                                     false,
                                      Gtk::MESSAGE_ERROR,
-                                     (Gtk::ButtonsType)(Gtk::BUTTONS_OK));
+                                     (Gtk::ButtonsType)(Gtk::BUTTONS_OK),
+                                     true);
         errdialog.run();
     }
     
@@ -285,9 +294,11 @@ mainwnd::file_saveas_dialog( void )
             if ( !result ){
                 
                 Gtk::MessageDialog errdialog(*this,
+                                              false,
                                              "Error writing file.",
                                              Gtk::MESSAGE_ERROR,
-                                             (Gtk::ButtonsType)(Gtk::BUTTONS_OK));
+                                             (Gtk::ButtonsType)(Gtk::BUTTONS_OK),
+                                             true );
                 errdialog.run();
             }
             
@@ -330,9 +341,10 @@ mainwnd::file_open_dialog( void )
             if ( !result ){
                 
                 Gtk::MessageDialog errdialog(*this,
-                                             "Error reading file.",
+                                             "Error reading file.", false,
                                              Gtk::MESSAGE_ERROR,
-                                             (Gtk::ButtonsType)(Gtk::BUTTONS_OK));
+                                             (Gtk::ButtonsType)(Gtk::BUTTONS_OK),
+                                             true);
                 errdialog.run();
             }
 
@@ -394,10 +406,11 @@ mainwnd::file_import_dialog( void )
            }
            catch(...){
                
-               Gtk::MessageDialog errdialog(*this,
-                                          "Error reading file.",
-                                          Gtk::MESSAGE_ERROR,
-                                          (Gtk::ButtonsType)(Gtk::BUTTONS_OK));
+               Gtk::MessageDialog errdialog(*this, 
+                                            "Error reading file.", false,
+                                            Gtk::MESSAGE_ERROR,
+                                            (Gtk::ButtonsType)(Gtk::BUTTONS_OK),
+                                            true);
                 errdialog.run();
                
            }
@@ -427,11 +440,11 @@ mainwnd::file_import_dialog( void )
 void
 mainwnd::file_exit_dialog( void )
 {
-
     Gtk::MessageDialog dialog(*this,
-                              "Quit seq24 ?",
+                              "Quit seq24 ?", false,
                               Gtk::MESSAGE_QUESTION,
-                              (Gtk::ButtonsType)(Gtk::BUTTONS_OK_CANCEL));
+                              (Gtk::ButtonsType)(Gtk::BUTTONS_OK_CANCEL),
+                              true);
     
     int result = dialog.run();
 
