@@ -20,6 +20,7 @@
 #include "midibus.h"
 #include "config.h"
 #include "sys/poll.h"
+#include "lash.h"
 
 midibus::midibus( int a_localclient,
 		  int a_destclient, 
@@ -835,6 +836,9 @@ mastermidibus::mastermidibus()
         m_buses_out_active[i] = false;
         m_buses_in_init[i] = false;	
         m_buses_out_init[i] = false;
+
+        m_init_clock[i] = e_clock_off;
+        m_init_input[i] = false;
     }
     
     /* open the sequencer client */
@@ -851,6 +855,8 @@ mastermidibus::mastermidibus()
     /* set up our clients queue */
     m_queue = snd_seq_alloc_queue( m_alsa_seq );
 
+	/* notify lash of our client ID so it can restore connections */
+	lash_driver->set_alsa_client_id(snd_seq_client_id(m_alsa_seq));
 }
 
 void
@@ -1006,6 +1012,15 @@ mastermidibus::init( )
                 0, m_queue);
 
     m_bus_announce->set_input(true);   
+
+
+    for ( int i=0; i<m_num_out_buses; i++ )
+        set_clock(i,m_init_clock[i]);
+
+    for ( int i=0; i<m_num_in_buses; i++ )
+        set_input(i,m_init_input[i]);
+
+    
 }
       
 mastermidibus::~mastermidibus()
@@ -1057,6 +1072,9 @@ void
 mastermidibus::set_clock( unsigned char a_bus, clock_e a_clock_type )
 {
     lock();
+    if ( a_bus < c_maxBuses ){
+        m_init_clock[a_bus] = a_clock_type;
+    }
     if ( m_buses_out_active[a_bus] && a_bus < m_num_out_buses ){
         m_buses_out[a_bus]->set_clock( a_clock_type );
     }
@@ -1075,7 +1093,8 @@ mastermidibus::get_clock( unsigned char a_bus )
 void 
 midibus::set_clock_mod( int a_clock_mod )
 {
-    m_clock_mod = a_clock_mod;
+    if (a_clock_mod != 0 )
+        m_clock_mod = a_clock_mod;
 }
 
 int 
@@ -1089,6 +1108,10 @@ void
 mastermidibus::set_input( unsigned char a_bus, bool a_inputing )
 {
     lock();
+    if ( a_bus < c_maxBuses ){
+        m_init_input[a_bus] = a_inputing;
+    }
+ 
     if ( m_buses_in_active[a_bus] && a_bus < m_num_in_buses ){
         m_buses_in[a_bus]->set_input( a_inputing );
     }
