@@ -168,6 +168,8 @@ class mastermidibus
     bool m_buses_out_init[c_maxBuses];
     bool m_buses_in_init[c_maxBuses];
 
+    clock_e m_init_clock[c_maxBuses];
+    bool m_init_input[c_maxBuses];
 
     /* id of queue */
     int m_queue;
