@@ -481,7 +481,7 @@ bool midifile::parse (perform * a_perf, int a_screen_set)
             unsigned long
                 seqs = read_long ();
 
-            for (int i = 0; i < seqs; i++)
+            for (unsigned int i = 0; i < seqs; i++)
             {
 
                 a_perf->get_midi_control_toggle (i)->m_active = m_d[m_pos++];
@@ -702,7 +702,7 @@ bool midifile::write (perform * a_perf)
             note = a_perf->get_screen_set_notepad (i);
         write_short (note->length ());
 
-        for (int j = 0; j < note->length (); j++)
+        for (unsigned int j = 0; j < note->length (); j++)
             m_l.push_front ((*note)[j]);
     }
 
