@@ -22,6 +22,7 @@
 #include "config.h"
 
 const pthread_mutex_t mutex::recmutex = PTHREAD_RECURSIVE_MUTEX_INITIALIZER_NP;
+const pthread_cond_t condition_var::cond  = PTHREAD_COND_INITIALIZER;
 
 mutex::mutex( )
 {
@@ -40,3 +41,23 @@ mutex::unlock( )
 {      
     pthread_mutex_unlock( &m_mutex_lock );
 }
+
+condition_var::condition_var( )
+{
+    m_cond = cond;
+}
+
+
+void
+condition_var::signal( )
+{
+    pthread_cond_signal( &m_cond );
+}
+
+void
+condition_var::wait( )
+{
+    pthread_cond_wait( &m_cond, &m_mutex_lock );
+}
+
+
