@@ -25,16 +25,18 @@
 #define SEQ24_MUTEX
 
 class mutex {
-
- private:
+    
+private:
 
     static const pthread_mutex_t recmutex;
-
+    
+protected:
+    
     /* mutex lock */
     pthread_mutex_t  m_mutex_lock;
-
- public:
-
+    
+public:
+    
     mutex();
 
     void lock();
@@ -42,4 +44,21 @@ class mutex {
 
 };
 
+class condition_var : public mutex {
+
+private:
+
+    static const pthread_cond_t cond;
+
+    pthread_cond_t m_cond;
+
+public:
+
+    condition_var();
+    
+    void wait();
+    void signal();
+    
+};
+
 #endif
