@@ -192,6 +192,13 @@ optionsfile::parse( perform *a_perf )
         a_perf->get_master_midi_bus( )->set_input( bus, (bool) bus_on );
         next_data_line( &file );
     }
+    
+    /* midi clock mod  */
+    long ticks = 64;
+    line_after( &file, "[midi-clock-mod-ticks]" );
+    sscanf( m_line, "%ld", &ticks );
+    midibus::set_clock_mod(ticks);
+
 
     /* manual alsa ports */
     line_after( &file, "[manual-alsa-ports]" );
@@ -288,6 +295,13 @@ optionsfile::write( perform *a_perf  )
         file << outs << "\n";
     }
 
+    /* midi clock mod  */
+    file << "\n\n[midi-clock-mod-ticks]\n";
+    file << midibus::get_clock_mod() << "\n";
+
+
+    
+
     /* bus input data */
     buses = a_perf->get_master_midi_bus( )->get_num_in_buses();
 
