@@ -28,6 +28,8 @@
 #include "collapse.xpm"
 #include "loop.xpm"
 #include "copy.xpm"
+#include "undo.xpm"
+#include "down.xpm"
 
 using namespace SigC;
 
@@ -74,7 +76,7 @@ perfedit::perfedit( perform *a_perf )
 
     m_button_grow = manage( new Button());
     m_button_grow->add( *manage( new Arrow( Gtk::ARROW_RIGHT, Gtk::SHADOW_OUT )));
-    m_button_grow->signal_clicked().connect( slot( *this, &perfedit::grow)); 
+    m_button_grow->signal_clicked().connect( mem_fun( *this, &perfedit::grow)); 
     m_tooltips->set_tip( *m_button_grow, "Increase size of Grid." );
 
 
@@ -97,79 +99,161 @@ perfedit::perfedit( perform *a_perf )
     m_table->attach( *m_button_grow, 2, 3, 3, 4, Gtk::SHRINK, Gtk::SHRINK  );
 
     m_menu_snap =   manage( new Menu());
-    m_menu_snap->items().push_back(MenuElem("1",     bind(slot(*this,&perfedit::set_snap), c_ppqn * 4  )));
-    m_menu_snap->items().push_back(MenuElem("1/2",   bind(slot(*this,&perfedit::set_snap), c_ppqn * 2  )));
-    m_menu_snap->items().push_back(MenuElem("1/4",   bind(slot(*this,&perfedit::set_snap), c_ppqn * 1  )));
-    m_menu_snap->items().push_back(MenuElem("1/8",   bind(slot(*this,&perfedit::set_snap), c_ppqn / 2  )));
+    m_menu_snap->items().push_back(MenuElem("1/1",     SigC::bind(mem_fun(*this,&perfedit::set_snap), 1  )));
+    m_menu_snap->items().push_back(MenuElem("1/2",   SigC::bind(mem_fun(*this,&perfedit::set_snap), 2  )));
+    m_menu_snap->items().push_back(MenuElem("1/4",   SigC::bind(mem_fun(*this,&perfedit::set_snap), 4  )));
+    m_menu_snap->items().push_back(MenuElem("1/8",   SigC::bind(mem_fun(*this,&perfedit::set_snap), 8  )));
+    m_menu_snap->items().push_back(MenuElem("1/16",   SigC::bind(mem_fun(*this,&perfedit::set_snap), 16  )));
+    m_menu_snap->items().push_back(MenuElem("1/32",   SigC::bind(mem_fun(*this,&perfedit::set_snap), 32  )));
  
+    
     /* snap */
     m_button_snap = manage( new Button());
     m_button_snap->add( *manage( new Image(Gdk::Pixbuf::create_from_xpm_data( snap_xpm ))));
-    m_button_snap->signal_clicked().connect(  bind<Menu *>( slot( *this, &perfedit::popup_menu), m_menu_snap  ));
-    m_tooltips->set_tip( *m_button_snap, "Grid snap." );
+    m_button_snap->signal_clicked().connect(  bind<Menu *>( mem_fun( *this, &perfedit::popup_menu), m_menu_snap  ));
+    m_tooltips->set_tip( *m_button_snap, "Grid snap. (Fraction of Measure Length)" );
     m_entry_snap = manage( new Entry());
     m_entry_snap->set_size_request( 40, -1 );
     m_entry_snap->set_editable( false );
 
+
+    m_menu_bpm = manage( new Menu() );
+    m_menu_bw = manage( new Menu() );
+
+    /* bw */
+    m_menu_bw->items().push_back(MenuElem("1", SigC::bind(mem_fun(*this,&perfedit::set_bw), 1  )));
+    m_menu_bw->items().push_back(MenuElem("2", SigC::bind(mem_fun(*this,&perfedit::set_bw), 2  )));
+    m_menu_bw->items().push_back(MenuElem("4", SigC::bind(mem_fun(*this,&perfedit::set_bw), 4  )));
+    m_menu_bw->items().push_back(MenuElem("8", SigC::bind(mem_fun(*this,&perfedit::set_bw), 8  )));
+    m_menu_bw->items().push_back(MenuElem("16", SigC::bind(mem_fun(*this,&perfedit::set_bw), 16 )));
+    
+    char b[20];
+    
+    for( int i=0; i<16; i++ ){
+        
+        sprintf( b, "%d", i+1 );
+        
+        /* length */
+        m_menu_bpm->items().push_back(MenuElem(b, 
+                                               SigC::bind(mem_fun(*this,&perfedit::set_bpm),   
+                                                    i+1 )));
+    }
+
+    
+    /* beats per measure */ 
+    m_button_bpm = manage( new Button());
+    m_button_bpm->add( *manage( new Image(Gdk::Pixbuf::create_from_xpm_data( down_xpm  ))));
+    m_button_bpm->signal_clicked().connect(  bind<Menu *>( mem_fun( *this, &perfedit::popup_menu), m_menu_bpm  ));
+    m_tooltips->set_tip( *m_button_bpm, "Time Signature. Beats per Measure" );
+    m_entry_bpm = manage( new Entry());
+    m_entry_bpm->set_width_chars(2);
+    m_entry_bpm->set_editable( false );
+
+
+    /* beat width */
+    m_button_bw = manage( new Button());
+    m_button_bw->add( *manage( new Image(Gdk::Pixbuf::create_from_xpm_data( down_xpm  ))));
+    m_button_bw->signal_clicked().connect(  bind<Menu *>( mem_fun( *this, &perfedit::popup_menu), m_menu_bw  ));
+    m_tooltips->set_tip( *m_button_bw, "Time Signature.  Length of Beat" );
+    m_entry_bw = manage( new Entry());
+    m_entry_bw->set_width_chars(2);
+    m_entry_bw->set_editable( false );
+
+/* undo */
+    m_button_undo = manage( new Button());
+    m_button_undo->add( *manage( new Image(Gdk::Pixbuf::create_from_xpm_data( undo_xpm  ))));
+    m_button_undo->signal_clicked().connect(  mem_fun( *this, &perfedit::undo));
+    m_tooltips->set_tip( *m_button_undo, "Undo." );
+ 
+
     /* expand */
     m_button_expand = manage( new Button());
     m_button_expand->add(*manage( new Image(Gdk::Pixbuf::create_from_xpm_data( expand_xpm ))));
-    m_button_expand->signal_clicked().connect(  slot( *this, &perfedit::expand));
+    m_button_expand->signal_clicked().connect(  mem_fun( *this, &perfedit::expand));
     m_tooltips->set_tip( *m_button_expand, "Expand between L and R markers." );
 
     /* collapse */
     m_button_collapse = manage( new Button());
     m_button_collapse->add(*manage( new Image(Gdk::Pixbuf::create_from_xpm_data( collapse_xpm ))));
-    m_button_collapse->signal_clicked().connect(  slot( *this, &perfedit::collapse));
+    m_button_collapse->signal_clicked().connect(  mem_fun( *this, &perfedit::collapse));
     m_tooltips->set_tip( *m_button_collapse, "Collapse between L and R markers." );
 
     /* copy */
     m_button_copy = manage( new Button());
     m_button_copy->add(*manage( new Image(Gdk::Pixbuf::create_from_xpm_data( copy_xpm ))));
-    m_button_copy->signal_clicked().connect(  slot( *this, &perfedit::copy ));
+    m_button_copy->signal_clicked().connect(  mem_fun( *this, &perfedit::copy ));
     m_tooltips->set_tip( *m_button_copy, "Expand and copy between L and R markers." );
 
 
     m_button_loop = manage( new ToggleButton() );
     m_button_loop->add(*manage( new Image(Gdk::Pixbuf::create_from_xpm_data( loop_xpm ))));
-    m_button_loop->signal_toggled().connect(  slot( *this, &perfedit::set_looped ));
+    m_button_loop->signal_toggled().connect(  mem_fun( *this, &perfedit::set_looped ));
     m_tooltips->set_tip( *m_button_loop, "Play looped between L and R." );
 
 
     m_button_stop = manage( new Button() );
     m_button_stop->add(*manage( new Image(Gdk::Pixbuf::create_from_xpm_data( stop_xpm ))));
-    m_button_stop->signal_clicked().connect( slot( *this, &perfedit::stop_playing));
+    m_button_stop->signal_clicked().connect( mem_fun( *this, &perfedit::stop_playing));
     m_tooltips->set_tip( *m_button_stop, "Stop playing." );
 
     m_button_play = manage( new Button() );
     m_button_play->add(*manage( new Image(Gdk::Pixbuf::create_from_xpm_data( play2_xpm ))));
-    m_button_play->signal_clicked().connect(  slot( *this, &perfedit::start_playing));
+    m_button_play->signal_clicked().connect(  mem_fun( *this, &perfedit::start_playing));
     m_tooltips->set_tip( *m_button_play, "Being playing at L marker." );
 
 
 
-  
-    m_hbox->pack_start( *m_button_snap , false, false );
-    m_hbox->pack_start( *m_entry_snap , false, false );
+
 
     m_hlbox->pack_end( *m_button_copy , false, false ); 
     m_hlbox->pack_end( *m_button_expand , false, false );
     m_hlbox->pack_end( *m_button_collapse , false, false );
+    m_hlbox->pack_end( *m_button_undo , false, false );
       
 
     m_hlbox->pack_start( *m_button_stop , false, false );
     m_hlbox->pack_start( *m_button_play , false, false );
     m_hlbox->pack_start( *m_button_loop , false, false );
 
+    m_hlbox->pack_start( *(manage(new VSeparator( ))), false, false, 4);
+
+    m_hlbox->pack_start( *m_button_bpm , false, false );
+    m_hlbox->pack_start( *m_entry_bpm , false, false );
+ 
+    m_hlbox->pack_start( *(manage(new Label( "/" ))), false, false, 4);
+
+
+    m_hlbox->pack_start( *m_button_bw , false, false );
+    m_hlbox->pack_start( *m_entry_bw , false, false );
+
+    m_hlbox->pack_start( *(manage(new Label( "x" ))), false, false, 4);
+  
+    m_hlbox->pack_start( *m_button_snap , false, false );
+    m_hlbox->pack_start( *m_entry_snap , false, false );
+    
+    
 
     /* add table */
     this->add( *m_table );
+   
+    m_snap = 8;
+    m_bpm = 4;
+    m_bw = 4;
 
-    set_snap(  c_ppqn * 4 );
+    set_snap( 8 );
+    set_bpm( 4 );
+    set_bw( 4 );
 }
  
  
 
+void 
+perfedit::undo( void )
+{
+    m_mainperf->pop_trigger_undo();
+    m_perfroll->queue_draw();
+}
+
 void 
 perfedit::start_playing( void )
 {
@@ -189,6 +273,7 @@ perfedit::stop_playing( void )
 void
 perfedit::collapse( void )
 {
+    m_mainperf->push_trigger_undo();
     m_mainperf->move_triggers( false );
     m_perfroll->queue_draw();
 }
@@ -196,6 +281,7 @@ perfedit::collapse( void )
 void
 perfedit::copy( void )
 {
+    m_mainperf->push_trigger_undo();
     m_mainperf->copy_triggers(  );
     m_perfroll->queue_draw();
 }
@@ -203,6 +289,7 @@ perfedit::copy( void )
 void 
 perfedit::expand( void )
 {
+    m_mainperf->push_trigger_undo();
     m_mainperf->move_triggers( true );
     m_perfroll->queue_draw();
 }
@@ -220,18 +307,51 @@ perfedit::popup_menu(Menu *a_menu)
     a_menu->popup(0,0);
 }
 
+void
+perfedit::set_guides( void )
+{
+    long measure_ticks = (c_ppqn * 4) * m_bpm / m_bw;
+    long snap_ticks =  measure_ticks / m_snap;
+    long beat_ticks = (c_ppqn * 4) / m_bw;
+    m_perfroll->set_guides( snap_ticks, measure_ticks, beat_ticks );
+    m_perftime->set_guides( snap_ticks, measure_ticks );
+}
+
 
 void 
 perfedit::set_snap( int a_snap  )
 {
     char b[10];
-    sprintf( b, "1/%d",   c_ppqn * 4 / a_snap );
+    sprintf( b, "1/%d", a_snap );
     m_entry_snap->set_text(b);
     
     m_snap = a_snap;
-    m_perfroll->set_snap( m_snap );
+    set_guides();
 }
 
+void perfedit::set_bpm( int a_beats_per_measure )
+{
+    char b[10];
+    sprintf( b, "%d", a_beats_per_measure );
+    m_entry_bpm->set_text(b);
+    
+    m_bpm = a_beats_per_measure;
+    set_guides();
+}
+
+
+void perfedit::set_bw( int a_beat_width )
+{
+    char b[10];
+    sprintf( b, "%d", a_beat_width );
+    m_entry_bw->set_text(b);
+    
+    m_bw = a_beat_width;
+    set_guides();
+}
+
+
+
 
 void 
 perfedit::on_realize()
@@ -239,7 +359,7 @@ perfedit::on_realize()
     // we need to do the default realize
     Gtk::Window::on_realize();
 
-    Glib::signal_timeout().connect(slot(*this,&perfedit::timeout ), c_redraw_ms);
+    Glib::signal_timeout().connect(mem_fun(*this,&perfedit::timeout ), c_redraw_ms);
   
   
  
@@ -253,10 +373,20 @@ perfedit::grow()
     m_perftime->increment_size();
 }
 
+void
+perfedit::init_before_show()
+{
+    m_perfroll->init_before_show();
+    //m_perftime->init_before_show();
+}
+
 bool
 perfedit::timeout( void )
 {
+
+    m_perfroll->redraw_dirty_sequences();
     m_perfroll->draw_progress();
+    m_perfnames->redraw_dirty_sequences();
    
     return true;
 }
