@@ -43,15 +43,17 @@
 #include <gtkmm/combo.h>
 #include <gtkmm/label.h>
 #include <gtkmm/toolbar.h>
-#include <gtkmm/optionmenu.h> 
+#include <gtkmm/optionmenu.h>
 #include <gtkmm/togglebutton.h>
 #include <gtkmm/invisible.h>
-#include <gtkmm/separator.h> 
+#include <gtkmm/separator.h>
 #include <gtkmm/tooltips.h>
 #include <gtkmm/invisible.h>
 #include <gtkmm/arrow.h>
 #include <gtkmm/image.h>
 
+#include <sigc++/bind.h>
+
 #include <list>
 #include <string>
 
@@ -65,14 +67,14 @@ using namespace Gtk;
 using namespace SigC;
 
 /* has a seqroll and paino roll */
-class perfedit : public Gtk::Window
+class perfedit:public Gtk::Window
 {
-   
- private:
- 
-    perform    *m_mainperf;
 
-    Table      *m_table;
+  private:
+
+    perform * m_mainperf;
+
+    Table *m_table;
 
     VScrollbar *m_vscroll;
     HScrollbar *m_hscroll;
@@ -81,61 +83,78 @@ class perfedit : public Gtk::Window
     Adjustment *m_hadjust;
 
 
-    perfnames  *m_perfnames;
-    perfroll   *m_perfroll;
-    perftime   *m_perftime;
+    perfnames *m_perfnames;
+    perfroll *m_perfroll;
+    perftime *m_perftime;
 
-    Menu       *m_menu_snap;
-    Button     *m_button_snap;
-    Entry      *m_entry_snap;
+    Menu *m_menu_snap;
+    Button *m_button_snap;
+    Entry *m_entry_snap;
 
-    Button     *m_button_stop;
-    Button     *m_button_play;
+    Button *m_button_stop;
+    Button *m_button_play;
     ToggleButton *m_button_loop;
 
-    Button     *m_button_expand;
-    Button     *m_button_collapse;
-    Button     *m_button_copy;
+    Button *m_button_expand;
+    Button *m_button_collapse;
+    Button *m_button_copy;
 
-    Button     *m_button_grow;
+    Button *m_button_grow;
+    Button *m_button_undo;
 
-    HBox       *m_hbox;
-    HBox       *m_hlbox;
+    Button      *m_button_bpm;
+    Entry       *m_entry_bpm;
 
-    Tooltips    *m_tooltips;
+    Button      *m_button_bw;
+    Entry       *m_entry_bw;    
 
-     /* set snap to in pulses */
-    int         m_snap;
+    HBox *m_hbox;
+    HBox *m_hlbox;
 
-    void set_snap( int a_snap );
-    void grow( void );
+    Tooltips *m_tooltips;
 
-    void on_realize();
-
-    void  start_playing( void );
-    void  stop_playing( void );
-
-    void set_looped( void );
-
-    void expand( void );
-    void collapse( void );
-    void copy( void );
-
-    void popup_menu(Menu *a_menu);
-
-    bool timeout( void );
-
-    bool on_delete_event(GdkEventAny *a_event);
-
- public:
-
-    perfedit( perform *a_perf  );
-
-    ~perfedit(  );
+    /* time signature, beats per measure, beat width */
+    Menu       *m_menu_bpm;
+    Menu       *m_menu_bw;
 
 
+    /* set snap to in pulses */
+    int m_snap;
+    int m_bpm;
+    int m_bw;
 
- 
+    void set_bpm( int a_beats_per_measure );
+    void set_bw( int a_beat_width );
+    void set_snap (int a_snap);
+
+    void set_guides( void );
+    
+    void grow (void);
+
+    void on_realize ();
+
+    void start_playing (void);
+    void stop_playing (void);
+
+    void set_looped (void);
+
+    void expand (void);
+    void collapse (void);
+    void copy (void);
+    void undo ( void );
+    
+    void popup_menu (Menu * a_menu);
+
+    bool timeout (void);
+
+    bool on_delete_event (GdkEventAny * a_event);
+
+  public:
+
+    void init_before_show ();
+
+    perfedit (perform * a_perf);
+    ~perfedit ();
 };
 
 
