@@ -175,7 +175,7 @@ perfnames::draw_sequence( int sequence )
                 
             char str[20];
             sprintf( str, 
-                     "%d-%d %d/%d", 
+                     "%d-%d %ld/%ld",
                      m_mainperf->get_sequence(sequence)->get_midi_bus(), 
                      m_mainperf->get_sequence(sequence)->get_midi_channel()+1,
                      m_mainperf->get_sequence(sequence)->get_bpm(),
@@ -260,7 +260,7 @@ perfnames::on_button_press_event(GdkEventButton *a_e)
 {
     int sequence;
     
-    int x = (int) a_e->x;
+    /*int x = (int) a_e->x;*/
     int y = (int) a_e->y;
     
     convert_y( y, &sequence );
@@ -279,11 +279,6 @@ perfnames::on_button_press_event(GdkEventButton *a_e)
         }
     }
     
-    /*     right mouse button      */
-    if ( a_e->button == 3 ){
-        popup_menu();    
-    }
-
     return true;
 }
 
@@ -291,6 +286,11 @@ perfnames::on_button_press_event(GdkEventButton *a_e)
 bool
 perfnames::on_button_release_event(GdkEventButton* p0)
 {
+    /*     right mouse button      */
+    if ( p0->button == 3 ){
+        popup_menu();    
+    }
+    
     return false;
 }
 
