@@ -24,6 +24,7 @@
 
 #include "perform.h"
 #include "sequence.h"
+#include "seqmenu.h"
 
 #include <gtkmm/button.h>
 #include <gtkmm/window.h>
@@ -44,7 +45,7 @@ using namespace Gtk;
 #include "globals.h"
 
 /* holds the left side piano */
-class perfnames : public Gtk::DrawingArea
+class perfnames : public virtual Gtk::DrawingArea, public virtual seqmenu
 {
  private: 
 
@@ -53,8 +54,6 @@ class perfnames : public Gtk::DrawingArea
     Gdk::Color    m_black, m_white, m_grey;
 
     Glib::RefPtr<Gdk::Pixmap>   m_pixmap;
-
-
    
     perform      *m_mainperf;
 
@@ -64,20 +63,28 @@ class perfnames : public Gtk::DrawingArea
 
     int          m_sequence_offset;
 
+    bool         m_sequence_active[c_total_seqs];
+
     void on_realize();
     bool on_expose_event(GdkEventExpose* a_ev);
     bool on_button_press_event(GdkEventButton* a_ev); 
     bool on_button_release_event(GdkEventButton* a_ev);
-    void on_size_allocate(GtkAllocation* );
+    void on_size_allocate(Gtk::Allocation& );
 
     void draw_area();
     void update_pixmap();
  
     void convert_y( int a_y, int *a_note);
 
+    void draw_sequence( int a_sequence );
+
     void change_vert( void );
+    
+    void redraw( int a_sequence );
 
  public:
+    
+    void redraw_dirty_sequences( void );
 
     perfnames( perform *a_perf,
 	       Adjustment *a_vadjust   );
