@@ -809,14 +809,14 @@ perform::position_jack( bool a_state )
     
     current_tick *= 10;
     
-    pos.bar  = (int) current_tick / (long) pos.ticks_per_beat / pos.beats_per_bar;
-    pos.beat = (int) (current_tick / (long) pos.ticks_per_beat) % 4; 
-    pos.tick = current_tick % (c_ppqn * 10);
+    pos.bar  = (int32_t) (current_tick / (long) pos.ticks_per_beat / pos.beats_per_bar);
+    pos.beat = (int32_t) ((current_tick / (long) pos.ticks_per_beat) % 4);
+    pos.tick = (int32_t) (current_tick % (c_ppqn * 10));
 
     pos.bar_start_tick = pos.bar * pos.beats_per_bar * pos.ticks_per_beat;
     pos.frame_rate = rate;
-    pos.frame = (current_tick * rate * 60.0)
-        / (pos.ticks_per_beat * pos.beats_per_minute);
+    pos.frame = (jack_nframes_t) ( (current_tick * rate * 60.0)
+        / (pos.ticks_per_beat * pos.beats_per_minute) );
 
     /*
     ticks * 10 = jack ticks;
@@ -1067,6 +1067,11 @@ int jack_sync_callback(jack_transport_state_t state,
           p->inner_start( global_jack_start_mode );
           break;
 
+      case JackTransportLooping:
+
+          //printf( "[JackTransportLooping]" );
+          break;
+
   }
 
   //printf( "starting frame[%d] tick[%8.2f]\n", p->m_jack_frame_current, p->m_jack_tick );
@@ -1253,7 +1258,7 @@ perform::output_func(void)
                                 //printf( "> current_tick[%lf]\n", current_tick );
                             }        
                             reset_sequences();
-                            set_orig_ticks( current_tick );
+                            set_orig_ticks( (long)current_tick );
                         }
                     }
                 }
@@ -1332,8 +1337,8 @@ perform::output_func(void)
                     //printf( " bbb [%2d:%2d:%4d]", pbar+1, pbeat+1, ptick );
                     //printf( " bbb [%2d:%2d:%4d]", m_jack_pos.bar, m_jack_pos.beat, m_jack_pos.tick );
 
-                    double jack_tick = (m_jack_pos.bar-1) * (m_jack_pos.ticks_per_beat *  m_jack_pos.beats_per_bar ) +
-                        (m_jack_pos.beat-1) * m_jack_pos.ticks_per_beat + m_jack_pos.tick;
+                    /*double jack_tick = (m_jack_pos.bar-1) * (m_jack_pos.ticks_per_beat *  m_jack_pos.beats_per_bar ) +
+                        (m_jack_pos.beat-1) * m_jack_pos.ticks_per_beat + m_jack_pos.tick;*/
 
                     //printf( " jtick[%8.3f]", m_jack_tick );
                     //printf( " mtick[%8.3f]", jack_tick );
@@ -1364,7 +1369,7 @@ perform::output_func(void)
             
             if( init_clock ) 
             {
-                m_master_bus.init_clock( clock_tick );
+                m_master_bus.init_clock( (long)clock_tick );
                 init_clock = false;
             }
             
@@ -1445,7 +1450,7 @@ perform::output_func(void)
             double next_clock_delta_us =  (( next_clock_delta ) * 60000000.0f / c_ppqn  / bpm );
 
             if ( next_clock_delta_us < (c_thread_trigger_width_ms * 1000.0f * 2.0f) ){
-                delta_us = next_clock_delta_us;
+                delta_us = (long)next_clock_delta_us;
             } 
 
 
@@ -1494,7 +1499,7 @@ perform::output_func(void)
                     stats_loop_index = 0;
                     stats_avg /= 200;
 
-                    printf( "stats_avg[%d]us stats_min[%d]us stats_max[%d]us\n", stats_avg, stats_min, stats_max );
+                    printf( "stats_avg[%ld]us stats_min[%ld]us stats_max[%ld]us\n", stats_avg, stats_min, stats_max );
 
                     stats_min = 0x7FFFFFFF;
                     stats_max = 0;
@@ -1513,16 +1518,16 @@ perform::output_func(void)
 
             printf ( "\n\n-- trigger width --\n" );
             for ( int i=0; i<100; i++ ){
-                printf( "[%3d][%8d]\n", i * 100, stats_all[i] );
+                printf( "[%3d][%8ld]\n", i * 100, stats_all[i] );
             }
             printf ( "\n\n-- clock width --\n" );
             int bpm  = m_master_bus.get_bpm();
 
-            printf ( "optimal : [%ld]us\n", ((c_ppqn / 24)* 60000000 / c_ppqn  / bpm )); 
+            printf ( "optimal : [%d]us\n", ((c_ppqn / 24)* 60000000 / c_ppqn  / bpm ));
 
 
             for ( int i=0; i<100; i++ ){
-                printf( "[%3d][%8d]\n", i * 300, stats_clock[i] );
+                printf( "[%3d][%8ld]\n", i * 300, stats_clock[i] );
             }
 
 
