@@ -74,6 +74,12 @@ class perform
     sequence *m_seqs[c_max_sequence];
 
     bool m_seqs_active[ c_max_sequence ];
+
+    bool m_was_active_main[ c_max_sequence ];
+    bool m_was_active_edit[ c_max_sequence ];
+    bool m_was_active_perf[ c_max_sequence ];
+    bool m_was_active_names[ c_max_sequence ];
+    
     bool m_sequence_state[  c_max_sequence ];
 
     /* our midibus */
@@ -156,18 +162,20 @@ class perform
     perform();
     ~perform();
 
-	void clear_all( void );
+    void init( void );
 
+    void clear_all( void );
+    
     void launch_input_thread( void );
     void launch_output_thread( void );
     void init_jack( void );
+    void deinit_jack( void );
     
     void add_sequence( sequence *a_seq, int a_perf );
     void delete_sequence( int a_num );
-	bool is_sequence_in_edit( int a_num );
-
-	void clear_sequence_triggers( int a_seq  );
-
+    bool is_sequence_in_edit( int a_num );
+    
+    void clear_sequence_triggers( int a_seq  );
 
 
     long get_tick( ) { return m_tick; };
@@ -183,6 +191,9 @@ class perform
 
     void move_triggers( bool a_direction );
     void copy_triggers(  );
+    
+    void push_trigger_undo( void );
+    void pop_trigger_undo( void );
 
     void print();
 
@@ -207,8 +218,14 @@ class perform
 
     void off_sequences( void );
 
+    void set_active(int a_sequence, bool a_active);
+    void set_was_active( int a_sequence );
     bool is_active(int a_sequence);
-
+    bool is_dirty_main (int a_sequence);
+    bool is_dirty_edit (int a_sequence);
+    bool is_dirty_perf (int a_sequence);
+    bool is_dirty_names (int a_sequence);
+        
     void new_sequence( int a_sequence );
 
     /* plays all notes to Curent tick */
@@ -230,22 +247,22 @@ class perform
     void sequence_playing_toggle( int a_sequence );
     void sequence_playing_on( int a_sequence );
     void sequence_playing_off( int a_sequence );
-
+    
+    void mute_all_tracks( void );
 
     mastermidibus* get_master_midi_bus( );
     
-	void output_func();
-	void input_func();
-
-
+    void output_func();
+    void input_func();
+    
     long get_max_trigger( void );
 
-	void set_offset( int a_offset );
-
-	void save_playing_state( void );
-	void restore_playing_state( void );
+    void set_offset( int a_offset );
+    
+    void save_playing_state( void );
+    void restore_playing_state( void );
+    
     
-
     std::map<long,long> *get_key_events( void ){ return &key_events; };
 
 
