@@ -800,7 +800,7 @@ perfroll::on_motion_notify_event(GdkEventMotion* a_ev)
             long seq_length = m_mainperf->get_sequence( m_drop_sequence )->get_length( );
             tick = tick - (tick % seq_length);
 
-            long min_tick = (tick < m_drop_tick) ? tick : m_drop_tick;
+            /*long min_tick = (tick < m_drop_tick) ? tick : m_drop_tick;*/
             long length = seq_length;
             
 	    m_mainperf->get_sequence( m_drop_sequence )->grow_trigger( m_drop_tick, tick, length);
