@@ -21,11 +21,13 @@
 #include <getopt.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include "config.h"
 #include "perform.h"
 #include "mainwnd.h"
 #include "midifile.h"
 #include "optionsfile.h"
 #include "font.h"
+#include "lash.h"
 
 /* struct for command parsing */
 static struct 
@@ -66,11 +68,15 @@ bool global_jack_start_mode = true;
 
 font *p_font_renderer;
 
+lash *lash_driver = NULL;
+
 bool load_file = false;
 
 int 
 main (int argc, char *argv[])
 {
+	/* init the lash driver (strips lash specific cmdline arguments */
+	lash_driver = new lash(&argc, &argv);
 
     /* the main performance object */
     perform p; 
@@ -96,7 +102,7 @@ main (int argc, char *argv[])
             
     } else {
         
-        printf( "Error calling getenv( \"HOME\" )" );  
+        printf( "Error calling getenv( \"HOME\" )\n" );  
     }
 
     
@@ -194,8 +200,6 @@ main (int argc, char *argv[])
 
             case 'm':
 
-                ////// too late for this!
-                
                 global_manual_alsa_ports = true;
                 break;
 
@@ -236,6 +240,8 @@ main (int argc, char *argv[])
     }
 
     mainwnd mainwnd( &p );
+
+	lash_driver->start( &p );
     kit.run();
     
     p.deinit_jack();
@@ -254,10 +260,10 @@ main (int argc, char *argv[])
             
     } else {
         
-        printf( "Error calling getenv( \"HOME\" )" );  
+        printf( "Error calling getenv( \"HOME\" )\n" );  
     }
 
-    
+	delete lash_driver;
 
     return 0;
 }
