@@ -106,7 +106,7 @@ class seqdata : public Gtk::DrawingArea
     
     void draw_events_on( Glib::RefPtr<Gdk::Drawable> a_draw );
 
-    void on_size_allocate(GtkAllocation* );    
+    void on_size_allocate(Gtk::Allocation& );    
     void change_horz( void );
 
     void force_draw( void );
