@@ -870,7 +870,7 @@ seqedit::set_background_sequence( int a_seq )
 
     if ( a_seq == -1 || !m_mainperf->is_active( a_seq )){
         m_entry_sequence->set_text("Off");
-         m_seqroll_wid->set_background_sequence( false, NULL );
+         m_seqroll_wid->set_background_sequence( false, 0 );
     }
     
     if ( m_mainperf->is_active( a_seq )){
