@@ -190,8 +190,8 @@ seqevent::draw_background()
                              m_window_y );
 
 
-   int measure_length_64ths =  m_seq->get_bpm() * 64 /
-        m_seq->get_bw();
+   /*int measure_length_64ths =  m_seq->get_bpm() * 64 /
+        m_seq->get_bw();*/
     
     //printf ( "measure_length_64ths[%d]\n", measure_length_64ths );
     
