@@ -44,7 +44,6 @@
 #include "seqdata.h"
 
 using namespace Gtk;
-using SigC::slot;
 
 /* piano event */
 class seqevent : public Gtk::DrawingArea
@@ -121,7 +120,7 @@ class seqevent : public Gtk::DrawingArea
 
     void start_paste( void );
 
-    void on_size_allocate(GtkAllocation* );    
+    void on_size_allocate(Gtk::Allocation& );    
     void change_horz( void );
 
     void force_draw( void );
