@@ -83,7 +83,7 @@ class seqkeys : public Gtk::DrawingArea
     int          m_key;
 
     void draw_key( int a_key, bool a_state );
-    void on_size_allocate(GtkAllocation* );
+    void on_size_allocate(Gtk::Allocation&);
     
     void change_vert( void );
     void force_draw( void );
