@@ -302,8 +302,8 @@ seqroll::draw_background()
     }
 
 
-    int measure_length_64ths =  m_seq->get_bpm() * 64 /
-        m_seq->get_bw();
+    /*int measure_length_64ths =  m_seq->get_bpm() * 64 /
+        m_seq->get_bw();*/
     
     //printf ( "measure_length_64ths[%d]\n", measure_length_64ths );
     
