@@ -260,75 +260,79 @@ sequence::play( long a_tick, bool a_playback_mode )
     long start_tick = m_last_tick;
     long end_tick = a_tick;
     long trigger_offset = 0;
+    
+    if (  m_song_mute )
+    {
+        set_playing(false);
+    }
+    else
+    {
 
-    /* if we are using our in sequence on/off triggers */
-    if ( a_playback_mode ){
+        /* if we are using our in sequence on/off triggers */
+        if ( a_playback_mode ){
 
-        bool trigger_state = false;
-        long trigger_tick = 0;
+            bool trigger_state = false;
+            long trigger_tick = 0;
 
 
-        list<trigger>::iterator i = m_list_trigger.begin();
+            list<trigger>::iterator i = m_list_trigger.begin();
 
-        while ( i != m_list_trigger.end()){
+            while ( i != m_list_trigger.end()){
 
-            if ( (*i).m_tick_start <= end_tick ){
-                trigger_state = true;
-                trigger_tick = (*i).m_tick_start;
-                trigger_offset = (*i).m_offset;
+                if ( (*i).m_tick_start <= end_tick ){
+                    trigger_state = true;
+                    trigger_tick = (*i).m_tick_start;
+                    trigger_offset = (*i).m_offset;
+                }
+
+                if ( (*i).m_tick_end <= end_tick ){
+                    trigger_state = false;
+                    trigger_tick = (*i).m_tick_end;
+                    trigger_offset = (*i).m_offset;
+                }
+
+                if ( (*i).m_tick_start >  end_tick ||
+                        (*i).m_tick_end   >  end_tick )
+                {
+                    break;
+                }
+
+                i++;
             }
 
-            if ( (*i).m_tick_end <= end_tick ){
-                trigger_state = false;
-                trigger_tick = (*i).m_tick_end;
-                trigger_offset = (*i).m_offset;
+            /* we had triggers in our slice and its not equal to current state */
+            if ( trigger_state != m_playing ){
+
+                //printf( "trigger %d\n", trigger_state );
+
+                /* we are turning on */
+                if ( trigger_state ){
+
+                    if ( trigger_tick < m_last_tick )
+                        start_tick = m_last_tick;
+                    else
+                        start_tick = trigger_tick;
+
+                    set_playing( true );
+
+                } else {
+
+                    /* we are on and turning off */
+                    end_tick = trigger_tick;
+                    trigger_turning_off = true;
+                }
+
             }
 
-            if ( (*i).m_tick_start >  end_tick ||
-                    (*i).m_tick_end   >  end_tick )
-            {
-                break;
-            }
+            if( m_list_trigger.size() == 0 && 
+                    m_playing ){
 
-            i++;
-        }
+                set_playing(false);
 
-        /* we had triggers in our slice and its not equal to current state */
-        if ( trigger_state != m_playing ){
-
-            //printf( "trigger %d\n", trigger_state );
-
-            /* we are turning on */
-            if ( trigger_state ){
-
-                if ( trigger_tick < m_last_tick )
-                    start_tick = m_last_tick;
-                else
-                    start_tick = trigger_tick;
-
-                set_playing( true );
-
-            } else {
-
-                /* we are on and turning off */
-                end_tick = trigger_tick;
-                trigger_turning_off = true;
             }
 
         }
-
-        if( m_list_trigger.size() == 0 && 
-                m_playing ){
-
-            set_playing(false);
-
-        }
-
-        if (  m_song_mute ){
-            set_playing(false);
-        }
-
-    }    
+    }
 
     set_trigger_offset(trigger_offset);
 
@@ -1826,7 +1830,7 @@ sequence::get_selected_trigger_end_tick( void )
 }
 
 
-bool
+void
 sequence::move_selected_triggers_to( long a_tick, bool a_adjust_offset, int a_which )
 {
 
@@ -2449,8 +2453,9 @@ sequence::set_playing( bool a_p )
             m_playing = false;
             off_playing_notes();
 
-        }
+        } 
 
+        //printf( "set_dirty\n");
         set_dirty();
     }
     
@@ -2546,7 +2551,7 @@ sequence::print()
 
     for( list<event>::iterator i = m_list_event.begin(); i != m_list_event.end(); i++ )
 	(*i).print();
-    printf("events[%d]\n\n",m_list_event.size());
+    printf("events[%zd]\n\n",m_list_event.size());
 
 }
 
@@ -2559,7 +2564,7 @@ sequence::print_triggers()
     for( list<trigger>::iterator i = m_list_trigger.begin();
          i != m_list_trigger.end(); i++ ){
 
-        long d= c_ppqn / 8;
+        /*long d= c_ppqn / 8;*/
         
         printf ("  tick_start[%ld] tick_end[%ld] off[%ld]\n", (*i).m_tick_start, (*i).m_tick_end, (*i).m_offset );
 
@@ -2572,7 +2577,7 @@ sequence::put_event_on_bus( event *a_e )
 {		
     lock();
 
-    char note = a_e->get_note();
+    unsigned char note = a_e->get_note();
     bool skip = false;
 	
     if ( a_e->is_note_on() ){
