@@ -284,7 +284,7 @@ class sequence
     void copy_selected_trigger( void );
     void paste_trigger( void );
     
-    bool move_selected_triggers_to(long a_tick, bool a_adjust_offset, int a_which=2);
+    void move_selected_triggers_to(long a_tick, bool a_adjust_offset, int a_which=2);
     long get_selected_trigger_start_tick( void );
     long get_selected_trigger_end_tick( void );
 
